import { DetectedFileInfo } from "../interfaces/dto";
import { FileInfo, FileSignature } from "../types";
export declare const FILE_TYPES_REQUIRED_ADDITIONAL_CHECK: Array<string>;
/**
 * A class hold all supported file typs with their unique signatures
 */
export declare class FileTypes {
    static AAC: FileInfo;
    static AMR: FileInfo;
    static FLAC: FileInfo;
    static M4A: FileInfo;
    static MP3: FileInfo;
    static WAV: FileInfo;
    static AVIF: FileInfo;
    static BMP: FileInfo;
    static BPG: FileInfo;
    static CR2: FileInfo;
    static EXR: FileInfo;
    static GIF: FileInfo;
    static ICO: FileInfo;
    static JPEG: FileInfo;
    static PBM: FileInfo;
    static PGM: FileInfo;
    static PNG: FileInfo;
    static PPM: FileInfo;
    static PSD: FileInfo;
    static WEBP: FileInfo;
    static HEIC: FileInfo;
    static AVI: FileInfo;
    static FLV: FileInfo;
    static M4V: FileInfo;
    static MKV: FileInfo;
    static MOV: FileInfo;
    static MP4: FileInfo;
    static OGG: FileInfo;
    static SWF: FileInfo;
    static WEBM: FileInfo;
    static _7Z: FileInfo;
    static LZH: FileInfo;
    static RAR: FileInfo;
    static ZIP: FileInfo;
    static BLEND: FileInfo;
    static DOC: FileInfo;
    static ELF: FileInfo;
    static EXE: FileInfo;
    static INDD: FileInfo;
    static MACHO: FileInfo;
    static ORC: FileInfo;
    static PARQUET: FileInfo;
    static PCAP: FileInfo;
    static PDF: FileInfo;
    static PS: FileInfo;
    static RTF: FileInfo;
    static SQLITE: FileInfo;
    static STL: FileInfo;
    static TTF: FileInfo;
    /**
     * Receive information on a file type by its property name from FileTypes class
     *
     * @param propertyName Property name from FileTypes class
     *
     * @returns {FileInfo} File type information
     */
    static getInfoByName(propertyName: string): FileInfo;
    /**
     * Receive an array of file type signatures by its property name from FileTypes class
     *
     * @param propertyName Property name from FileTypes class
     *
     * @returns {Array<FileSignature>} All unique signatures with their information
     */
    static getSignaturesByName(propertyName: string): Array<FileSignature>;
    /**
     * Determine if a valid signature exist in a file chunk
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param acceptedSignatures Valid signatures to search for in fileChunk
     *
     * @returns {boolean} True if found a valid signature inside the chunk, otherwise false
     */
    static detectSignature(fileChunk: Array<number>, acceptedSignatures: Array<FileSignature>): FileSignature | undefined;
    /**
     * Perfomrs an additional check for detected file types by their unique structure
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param detectedFiles A list of detected files
     * @returns {string | undefined} File type extension if found, otherwise undefined
     */
    static detectTypeByAdditionalCheck(fileChunk: Array<number>, detectedFiles: Array<DetectedFileInfo | FileInfo>): string | undefined;
    /**
     * Determine if a file chunk contains a valid signature and return the file signature if exist
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param acceptedSignatures Valid signatures to search for in fileChunk
     *
     * @returns {FileSignature | undefined } FileSignature if found a valid signature, otherwise undefined
     */
    static detectbBySignatures(fileChunk: Array<number>, acceptedSignatures: Array<FileSignature>): FileSignature | undefined;
    /**
     * Determine if file content contains a valid signature of a required type
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param type The file type to match against
     *
     * @returns {boolean} True if found a signature of the type in file content, otherwise false
     */
    static checkByFileType(fileChunk: Array<number>, type: string): boolean;
}
