import { FileValidatorOptions } from "../core";
/**
 * Determine if file content contains a valid 'aac' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 * @param options parameters for additional actions
 *
 * @returns {boolean} True if found a signature of type 'aac' in file content, otherwise false
 */
export declare function isAAC(file: Array<number> | ArrayBuffer | Uint8Array, options?: FileValidatorOptions): boolean;
/**
 * Determine if file content contains a valid 'amr' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'amr' in file content, otherwise false
 */
export declare function isAMR(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'flac' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'flac' in file content, otherwise false
 */
export declare function isFLAC(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'm4a' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'm4a' in file content, otherwise false
 */
export declare function isM4A(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'mp3' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'mp3' in file content, otherwise false
 */
export declare function isMP3(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'wav' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'wav' in file content, otherwise false
 */
export declare function isWAV(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
