import { ZipValidatorOptions } from "../core";
/**
 * Determine if file content contains a valid '7z' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type '7z' in file content, otherwise false
 */
export declare function is7Z(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'lzh' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'lzh' in file content, otherwise false
 */
export declare function isLZH(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'rar' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 *
 * @returns {boolean} True if found a signature of type 'rar' in file content, otherwise false
 */
export declare function isRAR(file: Array<number> | ArrayBuffer | Uint8Array): boolean;
/**
 * Determine if file content contains a valid 'zip' file signature
 *
 * @param file File content represents in Array<number> / ArrayBuffer / Uint8Array
 * @param options parameters for additional actions
 *
 * @returns {boolean} True if found a signature of type 'zip' in file content, otherwise false
 */
export declare function isZIP(file: Array<number> | ArrayBuffer | Uint8Array, options?: ZipValidatorOptions): boolean;
